@@ -28,6 +28,8 @@ test_that("get_sysdata returns all expected entries", {
 })
 
 test_that("sysdata gets downloaded", {
+  skip_on_cran()
+  skip_on_ci()
   gets_downloaded <- function(outfile) {
     if(file.exists(outfile)) {
       file.remove(outfile)
@@ -43,4 +45,4 @@ test_that("sysdata gets downloaded", {
   options(sdmpredictors_datadir = NULL)
   outfile <- paste0(tempdir(), "/sdmpredictors/", fname)
   gets_downloaded(outfile)
-})
\ No newline at end of file
+})
